/* Implementierung der BankKontoGUI, 
   die das ActionListener-Interface direkt implementiert 
*/

import java.awt.Container;
import java.awt.GridLayout;
import java.awt.Font;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class BankKontoGUI extends JFrame implements ActionListener {
  /* Attribute für GUI-Elemente */
  private JTextField kontoStandField;
  private JTextField betragField;
  private JButton einzahlenButton;
  private JButton abhebenButton;
  /* Referenz auf das Modell */
  private BankKonto konto;

  /* Konstruktor */
  public BankKontoGUI(BankKonto konto) {
    this.konto = konto;
    /* Titel und Groesse der GUI */
    this.setTitle("Bankkonto");
    this.setSize(700, 400);
    /* Schriftart anlegen, um groessere Schriften zu bekommen */        
    Font font1 = new Font("SansSerif", Font.BOLD, 40);
    /* Initialisierung der Attribute */
    this.kontoStandField = new JTextField(10);
    this.kontoStandField.setEditable(false);
    this.kontoStandField.setFont(font1);
    /* Setzen der Kontostand-Anzeige auf den
        Kontostand des Bankkontos */
    this.kontoStandField.setText(
            Double.toString(this.konto.getKontoStand()));
    this.betragField = new JTextField(10);
    this.betragField.setFont(font1);
    this.einzahlenButton = new JButton("Einzahlen");
    this.abhebenButton = new JButton("Abheben");
    this.einzahlenButton.setFont(font1);
    this.abhebenButton.setFont(font1);
    /* Baumstruktur anlegen und Layout setzen */
    JPanel kontoStandPanel = new JPanel(); // lokale Variable
    JLabel labelKontoStand = new JLabel("Kontostand:");
    labelKontoStand.setFont(font1);
    kontoStandPanel.add(labelKontoStand);
    kontoStandPanel.add(this.kontoStandField);
    JPanel betragPanel = new JPanel(); // lokale Variable
    JLabel labelBetrag = new JLabel("Betrag:");
    labelBetrag.setFont(font1);
    betragPanel.add(labelBetrag);
    betragPanel.add(this.betragField);
    JPanel buttonPanel = new JPanel(); // lokale Variable
    buttonPanel.add(this.einzahlenButton);
    buttonPanel.add(this.abhebenButton);
    Container contentPane = this.getContentPane();
    /* Grid mit 3 Zeilen und 1 Spalte */
    contentPane.setLayout(new GridLayout(3, 1));
    contentPane.add(kontoStandPanel);
    contentPane.add(betragPanel);
    contentPane.add(buttonPanel);
        
    /* Listener registrieren */
    this.einzahlenButton.addActionListener(this);
    this.abhebenButton.addActionListener(this);
 
     /* Für ordnungsgemäße Beendigung der Anwendung bei 
        Schließen (X) des Fensters */
    this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
  }
     
  /* Implementierung der Reaktionen auf Knopfdruck-Ereignisse */
    
  @Override
  public void actionPerformed(ActionEvent e) {
    Object source = e.getSource();
    // Pruefe, welcher Knopf gedrueckt wurde
    if (source == this.einzahlenButton) {
      // Einlesen des Betrags
       try { 
         double betrag = Double.parseDouble(this.betragField.getText());
         // Einzahlen auf Konto
         this.konto.einzahlen(betrag);
         // Ausgabe neuer Kontostand
         this.kontoStandField.setText(
                        Double.toString(this.konto.getKontoStand()));
       }
       catch (NumberFormatException ex) {
         this.kontoStandField.setText("Eingabefehler");
       }
      }
    
    else if (source == this.abhebenButton) {
      // Einlesen des Betrags
      try { 
        double betrag = Double.parseDouble(this.betragField.getText());
        // Abheben vom Konto
        this.konto.abheben(betrag);
        // Ausgabe neuer Kontostand
        this.kontoStandField.setText(
                        Double.toString(this.konto.getKontoStand()));
    }
       catch (NumberFormatException ex) {
         this.kontoStandField.setText("Eingabefehler");
       }
      }
    
  }
} 
